% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/runDR.R
\name{runDR}
\alias{runDR}
\title{Dimension reduction}
\usage{
runDR(x, dr = c("UMAP", "TSNE", "PCA", "MDS", "DiffusionMap"),
  cells = NULL, features = NULL, assay = "exprs", ...)
}
\arguments{
\item{x}{a \code{\link[SingleCellExperiment]{SingleCellExperiment}}.}

\item{dr}{character string specifying which dimension reduction to use.}

\item{cells}{single numeric specifying the maximal number of cells
per sample to use for dimension reduction; NULL for all cells.}

\item{features}{specifies the features to use for dimension reduction. 
Either a character string specifying a subset of features,
or NULL for all features. When \code{rowData(x)$marker_class} 
is specified, can be one of "type", "state", or "none".}

\item{assay}{character string specifying 
which assay of \code{x} conatins expression values.}

\item{...}{optional arguments for dimension reduction; passed to 
\code{\link[scater]{runUMAP}}, \code{\link[scater]{runTSNE}}, 
\code{\link[scater]{runPCA}}, \code{\link[scater]{runMDS}} and
\code{\link[scater]{runDiffusionMap}}, respecttively.
See \code{?"scater-red-dim-args"} for details.}
}
\value{
a \code{ggplot} object.
}
\description{
Wrapper around dimension reduction methods available 
through \code{scater}, with optional cell subsampling.
}
\examples{
# construct SCE
data(PBMC_fs, PBMC_panel, PBMC_md)
sce <- prepData(PBMC_fs, PBMC_panel, PBMC_md)

# run UMAP on <= 200 cells per sample
sce <- runDR(sce, features = type_markers(sce), cells = 100)

}
\references{
Nowicka M, Krieg C, Weber LM et al. 
CyTOF workflow: Differential discovery in 
high-throughput high-dimensional cytometry datasets.
\emph{F1000Research} 2017, 6:748 (doi: 10.12688/f1000research.11622.1)
}
\author{
Helena Lucia Crowell
}
